@@ -14,7 +14,7 @@ import re
 import numpy as np
 from cytoolz import itertoolz
 from spacy.parts_of_speech import CONJ, DET, NOUN, VERB
-from spacy.tokens.span import Span as SpacySpan
+from spacy.tokens import Span
 
 from . import compat
 from . import constants
@@ -22,15 +22,21 @@ from . import text_utils
 from .spacier import utils as spacy_utils
 
 
-def words(doc,
-          filter_stops=True, filter_punct=True, filter_nums=False,
-          include_pos=None, exclude_pos=None, min_freq=1):
+def words(
+    doc,
+    filter_stops=True,
+    filter_punct=True,
+    filter_nums=False,
+    include_pos=None,
+    exclude_pos=None,
+    min_freq=1,
+):
     """
     Extract an ordered sequence of words from a document processed by spaCy,
     optionally filtering words by part-of-speech tag and frequency.
 
     Args:
-        doc (``textacy.Doc``, ``spacy.Doc``, or ``spacy.Span``)
+        doc (:class:`spacy.tokens.Doc` or :class:`spacy.tokens.Span`)
         filter_stops (bool): if True, remove stop words from word list
         filter_punct (bool): if True, remove punctuation from word list
         filter_nums (bool): if True, remove number-like words (e.g. 10, 'ten')
@@ -43,7 +49,7 @@ def words(doc,
             ``min_freq`` times
 
     Yields:
-        ``spacy.Token``: the next token from ``doc`` passing specified filters
+        :class:`spacy.tokens.Token`: the next token from ``doc`` passing specified filters
         in order of appearance in the document
 
     Raises:
@@ -84,23 +90,29 @@ def words(doc,
     if min_freq > 1:
         words_ = list(words_)
         freqs = itertoolz.frequencies(w.lower_ for w in words_)
-        words_ = (w for w in words_
-                  if freqs[w.lower_] >= min_freq)
+        words_ = (w for w in words_ if freqs[w.lower_] >= min_freq)
 
     for word in words_:
         yield word
 
 
-def ngrams(doc, n,
-           filter_stops=True, filter_punct=True, filter_nums=False,
-           include_pos=None, exclude_pos=None, min_freq=1):
+def ngrams(
+    doc,
+    n,
+    filter_stops=True,
+    filter_punct=True,
+    filter_nums=False,
+    include_pos=None,
+    exclude_pos=None,
+    min_freq=1,
+):
     """
     Extract an ordered sequence of n-grams (``n`` consecutive words) from a
     spacy-parsed doc, optionally filtering n-grams by the types and
     parts-of-speech of the constituent words.
 
     Args:
-        doc (``textacy.Doc``, ``spacy.Doc``, or ``spacy.Span``)
+        doc (:class:`spacy.tokens.Doc` or :class:`spacy.tokens.Span`)
         n (int): number of tokens per n-gram; 2 => bigrams, 3 => trigrams, etc.
         filter_stops (bool): if True, remove ngrams that start or end
             with a stop word
@@ -116,7 +128,7 @@ def ngrams(doc, n,
             ``min_freq`` times
 
     Yields:
-        ``spacy.Span``: the next ngram from ``doc`` passing all specified
+        :class:`spacy.tokens.Span`: the next ngram from ``doc`` passing all specified
         filters, in order of appearance in the document
 
     Raises:
@@ -129,144 +141,151 @@ def ngrams(doc, n,
         check spaCy's docs: https://spacy.io/api/annotation#pos-tagging
     """
     if n < 1:
-        raise ValueError('n must be greater than or equal to 1')
+        raise ValueError("n must be greater than or equal to 1")
 
-    ngrams_ = (doc[i: i + n]
-               for i in compat.range_(len(doc) - n + 1))
-    ngrams_ = (ngram for ngram in ngrams_
-               if not any(w.is_space for w in ngram))
+    ngrams_ = (doc[i : i + n] for i in compat.range_(len(doc) - n + 1))
+    ngrams_ = (ngram for ngram in ngrams_ if not any(w.is_space for w in ngram))
     if filter_stops is True:
-        ngrams_ = (ngram for ngram in ngrams_
-                   if not ngram[0].is_stop and not ngram[-1].is_stop)
+        ngrams_ = (
+            ngram for ngram in ngrams_ if not ngram[0].is_stop and not ngram[-1].is_stop
+        )
     if filter_punct is True:
-        ngrams_ = (ngram for ngram in ngrams_
-                   if not any(w.is_punct for w in ngram))
+        ngrams_ = (ngram for ngram in ngrams_ if not any(w.is_punct for w in ngram))
     if filter_nums is True:
-        ngrams_ = (ngram for ngram in ngrams_
-                   if not any(w.like_num for w in ngram))
+        ngrams_ = (ngram for ngram in ngrams_ if not any(w.like_num for w in ngram))
     if include_pos:
         if isinstance(include_pos, compat.unicode_):
             include_pos = include_pos.upper()
-            ngrams_ = (ngram for ngram in ngrams_
-                       if all(w.pos_ == include_pos for w in ngram))
+            ngrams_ = (
+                ngram for ngram in ngrams_ if all(w.pos_ == include_pos for w in ngram)
+            )
         elif isinstance(include_pos, (set, frozenset, list, tuple)):
             include_pos = {pos.upper() for pos in include_pos}
-            ngrams_ = (ngram for ngram in ngrams_
-                       if all(w.pos_ in include_pos for w in ngram))
+            ngrams_ = (
+                ngram for ngram in ngrams_ if all(w.pos_ in include_pos for w in ngram)
+            )
         else:
             msg = 'invalid `include_pos` type: "{}"'.format(type(include_pos))
             raise TypeError(msg)
     if exclude_pos:
         if isinstance(exclude_pos, compat.unicode_):
             exclude_pos = exclude_pos.upper()
-            ngrams_ = (ngram for ngram in ngrams_
-                       if all(w.pos_ != exclude_pos for w in ngram))
+            ngrams_ = (
+                ngram for ngram in ngrams_ if all(w.pos_ != exclude_pos for w in ngram)
+            )
         elif isinstance(exclude_pos, (set, frozenset, list, tuple)):
             exclude_pos = {pos.upper() for pos in exclude_pos}
-            ngrams_ = (ngram for ngram in ngrams_
-                       if all(w.pos_ not in exclude_pos for w in ngram))
+            ngrams_ = (
+                ngram
+                for ngram in ngrams_
+                if all(w.pos_ not in exclude_pos for w in ngram)
+            )
         else:
             msg = 'invalid `exclude_pos` type: "{}"'.format(type(exclude_pos))
             raise TypeError(msg)
     if min_freq > 1:
         ngrams_ = list(ngrams_)
         freqs = itertoolz.frequencies(ngram.lower_ for ngram in ngrams_)
-        ngrams_ = (ngram for ngram in ngrams_
-                   if freqs[ngram.lower_] >= min_freq)
+        ngrams_ = (ngram for ngram in ngrams_ if freqs[ngram.lower_] >= min_freq)
 
     for ngram in ngrams_:
         yield ngram
 
 
-def named_entities(doc,
-                   include_types=None, exclude_types=None,
-                   drop_determiners=True, min_freq=1):
+def entities(doc, include_types=None, exclude_types=None, drop_determiners=True, min_freq=1):
     """
     Extract an ordered sequence of named entities (PERSON, ORG, LOC, etc.) from
-    a spacy-parsed doc, optionally filtering by entity types and frequencies.
+    a ``Doc``, optionally filtering by entity types and frequencies.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc``)
-        include_types (str or Set[str]): remove named entities whose type IS NOT
+        doc (:class:`spacy.tokens.Doc`)
+        include_types (str or Set[str]): remove entities whose type IS NOT
             in this param; if "NUMERIC", all numeric entity types ("DATE",
             "MONEY", "ORDINAL", etc.) are included
-        exclude_types (str or Set[str]): remove named entities whose type IS
+        exclude_types (str or Set[str]): remove entities whose type IS
             in this param; if "NUMERIC", all numeric entity types ("DATE",
             "MONEY", "ORDINAL", etc.) are excluded
         drop_determiners (bool): Remove leading determiners (e.g. "the")
-            from named entities (e.g. "the United States" => "United States").
+            from entities (e.g. "the United States" => "United States").
 
             .. note:: Entities from which a leading determiner has been removed
-               are, effectively, *new* entities, and not saved to the ``SpacyDoc``
+               are, effectively, *new* entities, and not saved to the ``Doc``
                from which they came. This is irritating but unavoidable, since
                this function is not meant to have side-effects on document state.
                If you're only using the text of the returned spans, this is no
                big deal, but watch out if you're counting on determiner-less
                entities associated with the doc downstream.
 
-        min_freq (int): remove named entities that occur in ``doc`` fewer
+        min_freq (int): remove entities that occur in ``doc`` fewer
             than ``min_freq`` times
 
     Yields:
-        ``spacy.Span``: the next named entity from ``doc`` passing all specified
-        filters in order of appearance in the document
+        :class:`spacy.tokens.Span`: the next entity from ``doc`` passing
+        all specified filters in order of appearance in the document
 
     Raises:
         TypeError: if ``include_types`` or ``exclude_types`` is not a str, a set of
             str, or a falsy value
     """
-    if hasattr(doc, "spacy_doc"):
-        nes = doc.spacy_doc.ents
-    else:
-        nes = doc.ents
-    include_types = _parse_ne_types(include_types, "include")
-    exclude_types = _parse_ne_types(exclude_types, "exclude")
+    ents = doc.ents
+    # HACK: spacy's models have been erroneously tagging whitespace as entities
+    # https://github.com/explosion/spaCy/commit/1e6725e9b734862e61081a916baf440697b9971e
+    ents = (ent for ent in ents if not ent.text.isspace())
+    include_types = _parse_ent_types(include_types, "include")
+    exclude_types = _parse_ent_types(exclude_types, "exclude")
     if include_types:
         if isinstance(include_types, compat.unicode_):
-            nes = (ne for ne in nes if ne.label_ == include_types)
+            ents = (ent for ent in ents if ent.label_ == include_types)
         elif isinstance(include_types, (set, frozenset, list, tuple)):
-            nes = (ne for ne in nes if ne.label_ in include_types)
+            ents = (ent for ent in ents if ent.label_ in include_types)
     if exclude_types:
         if isinstance(exclude_types, compat.unicode_):
-            nes = (ne for ne in nes if ne.label_ != exclude_types)
+            ents = (ent for ent in ents if ent.label_ != exclude_types)
         elif isinstance(exclude_types, (set, frozenset, list, tuple)):
-            nes = (ne for ne in nes if ne.label_ not in exclude_types)
+            ents = (ent for ent in ents if ent.label_ not in exclude_types)
     if drop_determiners is True:
-        nes = (
-            ne if ne[0].pos != DET else SpacySpan(ne.doc, ne.start + 1, ne.end, label=ne.label, vector=ne.vector)
-            for ne in nes)
+        ents = (
+            ent
+            if ent[0].pos != DET
+            else Span(
+                ent.doc, ent.start + 1, ent.end, label=ent.label, vector=ent.vector
+            )
+            for ent in ents
+        )
     if min_freq > 1:
-        nes = list(nes)
-        freqs = itertoolz.frequencies(ne.lower_ for ne in nes)
-        nes = (ne for ne in nes if freqs[ne.lower_] >= min_freq)
+        ents = list(ents)
+        freqs = itertoolz.frequencies(ent.lower_ for ent in ents)
+        ents = (ent for ent in ents if freqs[ent.lower_] >= min_freq)
 
-    for ne in nes:
-        yield ne
+    for ent in ents:
+        yield ent
 
 
-def _parse_ne_types(ne_types, which):
-    if not ne_types:
+def _parse_ent_types(ent_types, which):
+    if not ent_types:
         return None
-    elif isinstance(ne_types, compat.unicode_):
-        ne_types = ne_types.upper()
+    elif isinstance(ent_types, compat.unicode_):
+        ent_types = ent_types.upper()
         # replace the shorthand numeric case by its corresponding constant
-        if ne_types == "NUMERIC":
-            return constants.NUMERIC_NE_TYPES
+        if ent_types == "NUMERIC":
+            return constants.NUMERIC_ENT_TYPES
         else:
-            return ne_types
-    elif isinstance(ne_types, (set, frozenset, list, tuple)):
-        ne_types = {ne_type.upper() for ne_type in ne_types}
+            return ent_types
+    elif isinstance(ent_types, (set, frozenset, list, tuple)):
+        ent_types = {ent_type.upper() for ent_type in ent_types}
         # again, replace the shorthand numeric case by its corresponding constant
         # and include it in the set in case other types are specified
-        if any(ne_type == "NUMERIC" for ne_type in ne_types):
-            return ne_types.union(constants.NUMERIC_NE_TYPES)
+        if any(ent_type == "NUMERIC" for ent_type in ent_types):
+            return ent_types.union(constants.NUMERIC_ENT_TYPES)
         else:
-            return ne_types
+            return ent_types
     else:
         allowed_types = (None, compat.unicode_, set, frozenset, list, tuple)
         raise TypeError(
             "{}_types = {} is {}, which is not one of the allowed types: {}".format(
-                which, ne_types, type(ne_types), allowed_types))
+                which, ent_types, type(ent_types), allowed_types
+            )
+        )
 
 
 def noun_chunks(doc, drop_determiners=True, min_freq=1):
@@ -275,28 +294,23 @@ def noun_chunks(doc, drop_determiners=True, min_freq=1):
     filtering by frequency and dropping leading determiners.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc``)
+        doc (:class:`spacy.tokens.Doc`)
         drop_determiners (bool): remove leading determiners (e.g. "the")
             from phrases (e.g. "the quick brown fox" => "quick brown fox")
         min_freq (int): remove chunks that occur in ``doc`` fewer than
             ``min_freq`` times
 
     Yields:
-        ``spacy.Span``: the next noun chunk from ``doc`` in order of appearance
+        :class:`spacy.tokens.Span`: the next noun chunk from ``doc`` in order of appearance
         in the document
     """
-    if hasattr(doc, 'spacy_doc'):
-        ncs = doc.spacy_doc.noun_chunks
-    else:
-        ncs = doc.noun_chunks
+    ncs = doc.noun_chunks
     if drop_determiners is True:
-        ncs = (nc if nc[0].pos != DET else nc[1:]
-               for nc in ncs)
+        ncs = (nc if nc[0].pos != DET else nc[1:] for nc in ncs)
     if min_freq > 1:
         ncs = list(ncs)
         freqs = itertoolz.frequencies(nc.lower_ for nc in ncs)
-        ncs = (nc for nc in ncs
-               if freqs[nc.lower_] >= min_freq)
+        ncs = (nc for nc in ncs if freqs[nc.lower_] >= min_freq)
 
     for nc in ncs:
         yield nc
@@ -308,7 +322,7 @@ def pos_regex_matches(doc, pattern):
     part-of-speech tags match the specified regex pattern.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc`` or ``spacy.Span``)
+        doc (:class:`spacy.tokens.Doc` or :class:`spacy.tokens.Span`)
         pattern (str): Pattern of consecutive POS tags whose corresponding words
             are to be extracted, inspired by the regex patterns used in NLTK's
             `nltk.chunk.regexp`. Tags are uppercase, from the universal tag set;
@@ -324,18 +338,18 @@ def pos_regex_matches(doc, pattern):
             * prepositional phrase: r'<PREP> <DET>? (<NOUN>+<ADP>)* <NOUN>+'
 
     Yields:
-        ``spacy.Span``: the next span of consecutive tokens from ``doc`` whose
+        :class:`spacy.tokens.Span`: the next span of consecutive tokens from ``doc`` whose
         parts-of-speech match ``pattern``, in order of apperance
     """
     # standardize and transform the regular expression pattern...
-    pattern = re.sub(r'\s', '', pattern)
-    pattern = re.sub(r'<([A-Z]+)\|([A-Z]+)>', r'( (\1|\2))', pattern)
-    pattern = re.sub(r'<([A-Z]+)>', r'( \1)', pattern)
+    pattern = re.sub(r"\s", "", pattern)
+    pattern = re.sub(r"<([A-Z]+)\|([A-Z]+)>", r"( (\1|\2))", pattern)
+    pattern = re.sub(r"<([A-Z]+)>", r"( \1)", pattern)
 
-    tags = ' ' + ' '.join(tok.pos_ for tok in doc)
+    tags = " " + " ".join(tok.pos_ for tok in doc)
 
     for m in re.finditer(pattern, tags):
-        yield doc[tags[0:m.start()].count(' '):tags[0:m.end()].count(' ')]
+        yield doc[tags[0 : m.start()].count(" ") : tags[0 : m.end()].count(" ")]
 
 
 def subject_verb_object_triples(doc):
@@ -344,19 +358,18 @@ def subject_verb_object_triples(doc):
     spacy-parsed doc. Note that this only works for SVO languages.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc`` or ``spacy.Span``)
+        doc (:class:`spacy.tokens.Doc` or :class:`spacy.tokens.Span`)
 
     Yields:
-        Tuple[``spacy.Span``, ``spacy.Span``, ``spacy.Span``]: The next 3-tuple
-        of spans from ``doc`` representing a (subject, verb, object) triple,
-        in order of appearance.
+        Tuple[:class:`spacy.tokens.Span`]: The next 3-tuple of spans from ``doc``
+        representing a (subject, verb, object) triple, in order of appearance.
     """
     # TODO: What to do about questions, where it may be VSO instead of SVO?
     # TODO: What about non-adjacent verb negations?
     # TODO: What about object (noun) negations?
-    if isinstance(doc, SpacySpan):
+    if isinstance(doc, Span):
         sents = [doc]
-    else:  # textacy.Doc or spacy.Doc
+    else:  # spacy.Doc
         sents = doc.sents
 
     for sent in sents:
@@ -374,9 +387,14 @@ def subject_verb_object_triples(doc):
             # add adjacent auxiliaries to verbs, for context
             # and add compounds to compound nouns
             verb_span = spacy_utils.get_span_for_verb_auxiliaries(verb)
-            verb = sent[verb_span[0] - start_i: verb_span[1] - start_i + 1]
+            verb = sent[verb_span[0] - start_i : verb_span[1] - start_i + 1]
             for subj in subjs:
-                subj = sent[spacy_utils.get_span_for_compound_noun(subj)[0] - start_i: subj.i - start_i + 1]
+                subj = sent[
+                    spacy_utils.get_span_for_compound_noun(subj)[0]
+                    - start_i : subj.i
+                    - start_i
+                    + 1
+                ]
                 for obj in objs:
                     if obj.pos == NOUN:
                         span = spacy_utils.get_span_for_compound_noun(obj)
@@ -384,7 +402,7 @@ def subject_verb_object_triples(doc):
                         span = spacy_utils.get_span_for_verb_auxiliaries(obj)
                     else:
                         span = (obj.i, obj.i)
-                    obj = sent[span[0] - start_i: span[1] - start_i + 1]
+                    obj = sent[span[0] - start_i : span[1] - start_i + 1]
 
                     yield (subj, verb, obj)
 
@@ -396,7 +414,7 @@ def acronyms_and_definitions(doc, known_acro_defs=None):
     only the most frequently occurring definition is returned.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc`` or ``spacy.Span``)
+        doc (:class:`spacy.tokens.Doc` or :class:`spacy.tokens.Span`)
         known_acro_defs (dict): if certain acronym/definition pairs
             are known, pass them in as {acronym (str): definition (str)};
             algorithm will not attempt to find new definitions
@@ -417,9 +435,9 @@ def acronyms_and_definitions(doc, known_acro_defs=None):
             acro_defs[acro] = [(def_, 1.0)]
         known_acronyms = set(acro_defs.keys())
 
-    if isinstance(doc, SpacySpan):
+    if isinstance(doc, Span):
         sents = [doc]
-    else:  # textacy.Doc or spacy.Doc
+    else:  # spacy.Doc
         sents = doc.sents
 
     # iterate over sentences and their tokens
@@ -434,12 +452,14 @@ def acronyms_and_definitions(doc, known_acro_defs=None):
 
             # define definition search window(s)
             window_size = min(2 * len(token_), len(token_) + 5)
-            windows = [sent[max(i - window_size, 0): i],
-                       sent[min(i + 1, max_ind): min(i + window_size + 1, max_ind)]]
+            windows = [
+                sent[max(i - window_size, 0) : i],
+                sent[min(i + 1, max_ind) : min(i + window_size + 1, max_ind)],
+            ]
             # if candidate inside (X) or -X-, only look in pre-window
             if 0 < i < max_ind:
                 adjacent_tokens = sent[i - 1].text + sent[i + 1].text
-                if adjacent_tokens in {'()', '--', '––'}:
+                if adjacent_tokens in {"()", "--", "––"}:
                     windows.pop()
 
             # iterate over possible windows
@@ -450,7 +470,7 @@ def acronyms_and_definitions(doc, known_acro_defs=None):
                 if window_.isupper():
                     continue
                 # window can't contain separating punctuation
-                if '!' in window_ or '?' in window_ or ':' in window_ or ';' in window_:
+                if "!" in window_ or "?" in window_ or ":" in window_ or ";" in window_:
                     continue
                 # acronym definition can't contain itself: no ouroboros!
                 if token_ in window_:
@@ -459,19 +479,22 @@ def acronyms_and_definitions(doc, known_acro_defs=None):
                 if not any(char in window_ for char in token_):
                     continue
                 definition, confidence = _get_acronym_definition(
-                    token_, window, threshold=0.8)
+                    token_, window, threshold=0.8
+                )
                 if definition:
                     acro_defs[token_].append((definition, confidence))
 
             if not acro_defs.get(token_):
-                acro_defs[token_].append(('', 0.0))
+                acro_defs[token_].append(("", 0.0))
 
     # vote by confidence score in the case of multiple definitions
     for acro, defs in acro_defs.items():
         if len(defs) == 1:
             acro_defs[acro] = defs[0][0]
         else:
-            acro_defs[acro] = sorted(defs, key=operator.itemgetter(1), reverse=True)[0][0]
+            acro_defs[acro] = sorted(defs, key=operator.itemgetter(1), reverse=True)[0][
+                0
+            ]
 
     return dict(acro_defs)
 
@@ -482,7 +505,7 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
 
     Args:
         acronym (str): acronym for which definition is sought
-        window (``spacy.Span``): a span of tokens from which definition
+        window (:class:`spacy.tokens.Span`): a span of tokens from which definition
             extraction will be attempted
         threshold (float): minimum "confidence" in definition required
             for acceptance; valid values in [0.0, 1.0]; higher value => stricter threshold
@@ -495,6 +518,7 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
         Taghva, Kazem, and Jeff Gilbreth. "Recognizing acronyms and their definitions."
         International Journal on Document Analysis and Recognition 1.4 (1999): 191-198.
     """
+
     def build_lcs_matrix(X, Y):
         m = len(X)
         n = len(Y)
@@ -525,7 +549,9 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
                             vec[l] = k
                         vectors.append(vec)
                     else:
-                        parse_lcs_matrix(b, i + 1, j + 1, lcs_length - 1, stack, vectors)
+                        parse_lcs_matrix(
+                            b, i + 1, j + 1, lcs_length - 1, stack, vectors
+                        )
                     stack = []
         return vectors
 
@@ -533,40 +559,40 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
         vv = {}
         first = v.index(int(np.nanmin(v)))
         last = v.index(int(np.nanmax(v)))
-        vv['size'] = (last - first) + 1
-        vv['distance'] = len(v) - last
-        vv['stop_count'] = 0
-        vv['misses'] = 0
+        vv["size"] = (last - first) + 1
+        vv["distance"] = len(v) - last
+        vv["stop_count"] = 0
+        vv["misses"] = 0
         for i in compat.range_(first, last + 1):
-            if v[i] >= 0 and types[i] == 's':
-                vv['stop_count'] += 1
-            elif v[i] is None and types[i] not in ['s', 'h']:
-                vv['misses'] += 1
+            if v[i] >= 0 and types[i] == "s":
+                vv["stop_count"] += 1
+            elif v[i] is None and types[i] not in ["s", "h"]:
+                vv["misses"] += 1
         return vv
 
     def compare_vectors(A, B, types):
         vv_A = vector_values(A, types)
         vv_B = vector_values(B, types)
         # no one-letter matches, sorryboutit
-        if vv_A['size'] == 1:
+        if vv_A["size"] == 1:
             return B
-        elif vv_B['size'] == 1:
+        elif vv_B["size"] == 1:
             return A
-        if vv_A['misses'] > vv_B['misses']:
+        if vv_A["misses"] > vv_B["misses"]:
             return B
-        elif vv_A['misses'] < vv_B['misses']:
+        elif vv_A["misses"] < vv_B["misses"]:
             return A
-        if vv_A['stop_count'] > vv_B['stop_count']:
+        if vv_A["stop_count"] > vv_B["stop_count"]:
             return B
-        if vv_A['stop_count'] < vv_B['stop_count']:
+        if vv_A["stop_count"] < vv_B["stop_count"]:
             return A
-        if vv_A['distance'] > vv_B['distance']:
+        if vv_A["distance"] > vv_B["distance"]:
             return B
-        elif vv_A['distance'] < vv_B['distance']:
+        elif vv_A["distance"] < vv_B["distance"]:
             return A
-        if vv_A['size'] > vv_B['size']:
+        if vv_A["size"] > vv_B["size"]:
             return B
-        elif vv_A['size'] < vv_B['size']:
+        elif vv_A["size"] < vv_B["size"]:
             return A
         return A
 
@@ -577,28 +603,30 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
         tok_text = tok.text
         if tok.is_stop:
             def_leads.append(tok_text[0])
-            def_types.append('s')
+            def_types.append("s")
         elif text_utils.is_acronym(tok_text):
             def_leads.append(tok_text[0])
-            def_types.append('a')
-        elif '-' in tok_text and not tok_text.startswith('-'):
-            tok_split = [t[0] for t in tok_text.split('-') if t]
+            def_types.append("a")
+        elif "-" in tok_text and not tok_text.startswith("-"):
+            tok_split = [t[0] for t in tok_text.split("-") if t]
             def_leads.extend(tok_split)
-            def_types.extend('H' if i == 0 else 'h' for i in compat.range_(len(tok_split)))
+            def_types.extend(
+                "H" if i == 0 else "h" for i in compat.range_(len(tok_split))
+            )
         else:
             def_leads.append(tok_text[0])
-            def_types.append('w')
-    def_leads = ''.join(def_leads).lower()
-    def_types = ''.join(def_types)
+            def_types.append("w")
+    def_leads = "".join(def_leads).lower()
+    def_types = "".join(def_types)
 
     # extract alphanumeric characters from acronym
-    acr_leads = ''.join(c for c in acronym if c.isalnum())
+    acr_leads = "".join(c for c in acronym if c.isalnum())
     # handle special cases of '&' and trailing 's'
-    acr_leads = acr_leads.replace('&', 'a')
-    if acr_leads.endswith('s'):
+    acr_leads = acr_leads.replace("&", "a")
+    if acr_leads.endswith("s"):
         # bail out if it's only a 2-letter acronym to start with, e.g. 'Is'
         if len(acr_leads) == 2:
-            return ('', 0)
+            return ("", 0)
         acr_leads = acr_leads[:-1]
     acr_leads = acr_leads.lower()
 
@@ -608,13 +636,13 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
     lcs_length = c[c.shape[0] - 1, c.shape[1] - 1]
     confidence = lcs_length / len(acronym)
     if confidence < threshold:
-        return ('', confidence)
+        return ("", confidence)
 
     vecs = parse_lcs_matrix(b, 0, 0, lcs_length, [], [])
     # first letter of acronym must be present
     vecs = [vec for vec in vecs if 0 in vec]
     if not vecs:
-        return ('', confidence)
+        return ("", confidence)
 
     best_vec = vecs[0]
     for vec in vecs[1:]:
@@ -623,21 +651,22 @@ def _get_acronym_definition(acronym, window, threshold=0.8):
     first = best_vec.index(int(np.nanmin(best_vec)))
     last = best_vec.index(int(np.nanmax(best_vec)))
 
-    definition = window[first: last + 1].text
+    definition = window[first : last + 1].text
     if len(definition.split()) == 1:
-        return ('', confidence)
+        return ("", confidence)
 
     return (definition, confidence)
 
 
-def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
-                              min_n_words=1, max_n_words=20):
+def semistructured_statements(
+    doc, entity, cue="be", ignore_entity_case=True, min_n_words=1, max_n_words=20
+):
     """
     Extract "semi-structured statements" from a spacy-parsed doc, each as a
     (entity, cue, fragment) triple. This is similar to subject-verb-object triples.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc``)
+        doc (:class:`spacy.tokens.Doc`)
         entity (str): a noun or noun phrase of some sort (e.g. "President Obama",
             "global warming", "Python")
         cue (str): verb lemma with which ``entity`` is associated
@@ -647,7 +676,7 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
         max_n_words (int): max number of tokens allowed in a matching fragment
 
     Yields:
-        (``spacy.Span`` or ``spacy.Token``, ``spacy.Span`` or ``spacy.Token``, ``spacy.Span``):
+        (:class:`spacy.tokens.Span` or :class:`spacy.tokens.Token`, :class:`spacy.tokens.Span` or :class:`spacy.tokens.Token`, :class:`spacy.tokens.Span`):
         where each element is a matching (entity, cue, fragment) triple
 
     Notes:
@@ -660,15 +689,15 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
         the Web. In Proc. ICETAL 2010, LNAI 6233, 345-356. Heidelberg, Springer.
     """
     if ignore_entity_case is True:
-        entity_toks = entity.lower().split(' ')
+        entity_toks = entity.lower().split(" ")
         get_tok_text = lambda x: x.lower_
     else:
-        entity_toks = entity.split(' ')
+        entity_toks = entity.split(" ")
         get_tok_text = lambda x: x.text
     first_entity_tok = entity_toks[0]
     n_entity_toks = len(entity_toks)
     cue = cue.lower()
-    cue_toks = cue.split(' ')
+    cue_toks = cue.split(" ")
     n_cue_toks = len(cue_toks)
 
     def is_good_last_tok(tok):
@@ -689,8 +718,11 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
                 the_entity_root = the_entity
             if tok.i + n_cue_toks >= len(doc):
                 continue
-            elif all(get_tok_text(tok.nbor(i=i + 1)) == et for i, et in enumerate(entity_toks[1:])):
-                the_entity = doc[tok.i: tok.i + n_entity_toks]
+            elif all(
+                get_tok_text(tok.nbor(i=i + 1)) == et
+                for i, et in enumerate(entity_toks[1:])
+            ):
+                the_entity = doc[tok.i : tok.i + n_entity_toks]
                 the_entity_root = the_entity.root
             else:
                 continue
@@ -703,10 +735,12 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
                 min_cue_i = terh.i
                 max_cue_i = terh.i + n_cue_toks
                 the_cue = terh
-            elif all(terh.nbor(i=i + 1).lemma_ == ct for i, ct in enumerate(cue_toks[1:])):
+            elif all(
+                terh.nbor(i=i + 1).lemma_ == ct for i, ct in enumerate(cue_toks[1:])
+            ):
                 min_cue_i = terh.i
                 max_cue_i = terh.i + n_cue_toks
-                the_cue = doc[terh.i: max_cue_i]
+                the_cue = doc[terh.i : max_cue_i]
             else:
                 continue
             if the_entity_root in the_cue.rights:
@@ -714,17 +748,26 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
 
             # now add adjacent auxiliary and negating tokens to the cue, for context
             try:
-                min_cue_i = min(left.i for left in itertools.takewhile(
-                    lambda x: x.dep_ in {'aux', 'neg'}, reversed(list(the_cue.lefts))))
+                min_cue_i = min(
+                    left.i
+                    for left in itertools.takewhile(
+                        lambda x: x.dep_ in {"aux", "neg"},
+                        reversed(list(the_cue.lefts)),
+                    )
+                )
             except ValueError:
                 pass
             try:
-                max_cue_i = max(right.i for right in itertools.takewhile(
-                    lambda x: x.dep_ in {'aux', 'neg'}, the_cue.rights))
+                max_cue_i = max(
+                    right.i
+                    for right in itertools.takewhile(
+                        lambda x: x.dep_ in {"aux", "neg"}, the_cue.rights
+                    )
+                )
             except ValueError:
                 pass
             if max_cue_i - min_cue_i > 1:
-                the_cue = doc[min_cue_i: max_cue_i]
+                the_cue = doc[min_cue_i:max_cue_i]
             else:
                 the_cue = doc[min_cue_i]
 
@@ -737,12 +780,16 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
             while is_good_last_tok(doc[max_frag_i]) is False:
                 max_frag_i -= 1
             n_fragment_toks = max_frag_i - min_frag_i
-            if n_fragment_toks <= 0 or n_fragment_toks < min_n_words or n_fragment_toks > max_n_words:
+            if (
+                n_fragment_toks <= 0
+                or n_fragment_toks < min_n_words
+                or n_fragment_toks > max_n_words
+            ):
                 continue
             # HACK...
             if min_frag_i == max_cue_i - 1:
                 min_frag_i += 1
-            the_fragment = doc[min_frag_i: max_frag_i + 1]
+            the_fragment = doc[min_frag_i : max_frag_i + 1]
 
             yield (the_entity, the_cue, the_fragment)
 
@@ -753,10 +800,10 @@ def direct_quotations(doc):
     or mixed quotations) using rules and patterns. English only.
 
     Args:
-        doc (``textacy.Doc`` or ``spacy.Doc``)
+        doc (:class:`spacy.tokens.Doc`)
 
     Yields:
-        (``spacy.Span``, ``spacy.Token``, ``spacy.Span``): next quotation in ``doc``
+        (:class:`spacy.tokens.Span`, :class:`spacy.tokens.Token`, :class:`spacy.tokens.Span`): next quotation in ``doc``
         represented as a (speaker, reporting verb, quotation) 3-tuple
 
     Notes:
@@ -765,23 +812,24 @@ def direct_quotations(doc):
 
     TODO: Better approach would use ML, but needs a training dataset.
     """
-    if hasattr(doc, 'spacy_doc'):
-        doc_lang = doc.lang
-        doc = doc.spacy_doc
-    else:
-        doc_lang = doc.vocab.lang
-    if doc_lang != 'en':
-        raise NotImplementedError('sorry, English-language texts only :(')
-    quote_end_punct = {',', '.', '?', '!'}
-    quote_indexes = set(itertoolz.concat(
-        (m.start(), m.end() - 1) for m in re.finditer(r"(\".*?\")|(''.*?'')|(``.*?'')", doc.text)))
-    quote_positions = list(itertoolz.partition(
-        2, sorted(tok.i for tok in doc if tok.idx in quote_indexes)))
+    doc_lang = doc.vocab.lang
+    if doc_lang != "en":
+        raise NotImplementedError("sorry, English-language texts only :(")
+    quote_end_punct = {",", ".", "?", "!"}
+    quote_indexes = set(
+        itertoolz.concat(
+            (m.start(), m.end() - 1)
+            for m in re.finditer(r"(\".*?\")|(''.*?'')|(``.*?'')", doc.text)
+        )
+    )
+    quote_positions = list(
+        itertoolz.partition(2, sorted(tok.i for tok in doc if tok.idx in quote_indexes))
+    )
     sents = list(doc.sents)
     sent_positions = [(sent.start, sent.end) for sent in sents]
 
     for q0, q1 in quote_positions:
-        quote = doc[q0: q1 + 1]
+        quote = doc[q0 : q1 + 1]
 
         # we're only looking for direct quotes, not indirect or mixed
         if not any(char in quote_end_punct for char in quote.text[-4:]):
@@ -800,11 +848,14 @@ def direct_quotations(doc):
             sent = sents[si]
 
             # get any reporting verbs
-            rvs = [tok for tok in sent
-                   if spacy_utils.preserve_case(tok) is False and
-                   tok.lemma_ in constants.REPORTING_VERBS and
-                   tok.pos_ == 'VERB' and
-                   not any(oq0 <= tok.i <= oq1 for oq0, oq1 in quote_positions)]
+            rvs = [
+                tok
+                for tok in sent
+                if spacy_utils.preserve_case(tok) is False
+                and tok.lemma_ in constants.REPORTING_VERBS
+                and tok.pos_ == "VERB"
+                and not any(oq0 <= tok.i <= oq1 for oq0, oq1 in quote_positions)
+            ]
 
             # get target offset against which to measure distances of NEs
             if rvs:
@@ -828,15 +879,15 @@ def direct_quotations(doc):
                 rv_subj = spacy_utils.get_subjects_of_verb(rv)[0]
             except IndexError:
                 continue
-    #         if rv_subj.text in {'he', 'she'}:
-    #             for ne in named_entities(doc, good_ne_types={'PERSON'}):
-    #                 if ne.start < rv_subj.i:
-    #                     speaker = ne
-    #                 else:
-    #                     break
-    #         else:
+            #         if rv_subj.text in {'he', 'she'}:
+            #             for ne in entities(doc, include_types={'PERSON'}):
+            #                 if ne.start < rv_subj.i:
+            #                     speaker = ne
+            #                 else:
+            #                     break
+            #         else:
             span = spacy_utils.get_span_for_compound_noun(rv_subj)
-            speaker = doc[span[0]: span[1] + 1]
+            speaker = doc[span[0] : span[1] + 1]
 
             yield (speaker, rv, quote)
             break
