@@ -10,44 +10,26 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import re
 import unicodedata
 
-from ftfy import fix_text
-from unidecode import unidecode
-
 from . import constants
 
 
-def fix_bad_unicode(text, normalization='NFC'):
+def fix_bad_unicode(text, normalization="NFC"):
     """
-    Fix unicode text that's "broken" using `ftfy <http://ftfy.readthedocs.org/>`_;
+    Fix unicode text that's "broken" using `ftfy <https://ftfy.readthedocs.io>`_;
     this includes mojibake, HTML entities and other code cruft,
     and non-standard forms for display purposes.
 
-    Args:
-        text (str): raw text
-        normalization ({'NFC', 'NFKC', 'NFD', 'NFKD'}): if 'NFC',
-            combines characters and diacritics written using separate code points,
-            e.g. converting "e" plus an acute accent modifier into "é"; unicode
-            can be converted to NFC form without any change in its meaning!
-            if 'NFKC', additional normalizations are applied that can change
-            the meanings of characters, e.g. ellipsis characters will be replaced
-            with three periods
-
-    Returns:
-        str
+    Warning:
+        As of v0.7.0, this is no longer implemented within textacy. Instead,
+        install and import ``ftfy`` independently, then call ``ftfy.fix_text(text)``
+        with a much larger variety of params, as needed for your use case.
     """
-    return fix_text(text, normalization=normalization)
-
-
-def transliterate_unicode(text):
-    """
-    Try to represent unicode data in ascii characters similar to what a human
-    with a US keyboard would choose.
-
-    Works great for languages of Western origin, worse the farther the language
-    gets from Latin-based alphabets. It's based on hand-tuned character mappings
-    that also contain ascii approximations for symbols and non-Latin alphabets.
-    """
-    return unidecode(text)
+    return NotImplementedError(
+        "As of v0.7.0, :func:`fix_bad_unicode()` is no longer implemented in textacy. "
+        "Instead, install and import ``ftfy`` directly, and call ``ftfy.fix_text(text)`` ,"
+        "which is more extensive and customizable than textacy's wrapper of it."
+        "For details, check out https://ftfy.readthedocs.io."
+    )
 
 
 def normalize_whitespace(text):
@@ -55,7 +37,9 @@ def normalize_whitespace(text):
     Given ``text`` str, replace one or more spacings with a single space, and one
     or more linebreaks with a single newline. Also strip leading/trailing whitespace.
     """
-    return constants.NONBREAKING_SPACE_REGEX.sub(' ', constants.LINEBREAK_REGEX.sub(r'\n', text)).strip()
+    return constants.RE_NONBREAKING_SPACE.sub(
+        " ", constants.RE_LINEBREAK.sub(r"\n", text)
+    ).strip()
 
 
 def unpack_contractions(text):
@@ -65,10 +49,22 @@ def unpack_contractions(text):
     so are left as-is.
     """
     # standard
-    text = re.sub(r"(\b)([Aa]re|[Cc]ould|[Dd]id|[Dd]oes|[Dd]o|[Hh]ad|[Hh]as|[Hh]ave|[Ii]s|[Mm]ight|[Mm]ust|[Ss]hould|[Ww]ere|[Ww]ould)n't", r"\1\2 not", text)
-    text = re.sub(r"(\b)([Hh]e|[Ii]|[Ss]he|[Tt]hey|[Ww]e|[Ww]hat|[Ww]ho|[Yy]ou)'ll", r"\1\2 will", text)
+    text = re.sub(
+        r"(\b)([Aa]re|[Cc]ould|[Dd]id|[Dd]oes|[Dd]o|[Hh]ad|[Hh]as|[Hh]ave|[Ii]s|[Mm]ight|[Mm]ust|[Ss]hould|[Ww]ere|[Ww]ould)n't",
+        r"\1\2 not",
+        text,
+    )
+    text = re.sub(
+        r"(\b)([Hh]e|[Ii]|[Ss]he|[Tt]hey|[Ww]e|[Ww]hat|[Ww]ho|[Yy]ou)'ll",
+        r"\1\2 will",
+        text,
+    )
     text = re.sub(r"(\b)([Tt]hey|[Ww]e|[Ww]hat|[Ww]ho|[Yy]ou)'re", r"\1\2 are", text)
-    text = re.sub(r"(\b)([Ii]|[Ss]hould|[Tt]hey|[Ww]e|[Ww]hat|[Ww]ho|[Ww]ould|[Yy]ou)'ve", r"\1\2 have", text)
+    text = re.sub(
+        r"(\b)([Ii]|[Ss]hould|[Tt]hey|[Ww]e|[Ww]hat|[Ww]ho|[Ww]ould|[Yy]ou)'ve",
+        r"\1\2 have",
+        text,
+    )
     # non-standard
     text = re.sub(r"(\b)([Cc]a)n't", r"\1\2n not", text)
     text = re.sub(r"(\b)([Ii])'m", r"\1\2 am", text)
@@ -79,24 +75,26 @@ def unpack_contractions(text):
     return text
 
 
-def replace_urls(text, replace_with='*URL*'):
+def replace_urls(text, replace_with="*URL*"):
     """Replace all URLs in ``text`` str with ``replace_with`` str."""
-    return constants.URL_REGEX.sub(replace_with, constants.SHORT_URL_REGEX.sub(replace_with, text))
+    return constants.RE_URL.sub(
+        replace_with, constants.RE_SHORT_URL.sub(replace_with, text)
+    )
 
 
-def replace_emails(text, replace_with='*EMAIL*'):
+def replace_emails(text, replace_with="*EMAIL*"):
     """Replace all emails in ``text`` str with ``replace_with`` str."""
-    return constants.EMAIL_REGEX.sub(replace_with, text)
+    return constants.RE_EMAIL.sub(replace_with, text)
 
 
-def replace_phone_numbers(text, replace_with='*PHONE*'):
+def replace_phone_numbers(text, replace_with="*PHONE*"):
     """Replace all phone numbers in ``text`` str with ``replace_with`` str."""
-    return constants.PHONE_REGEX.sub(replace_with, text)
+    return constants.RE_PHONE.sub(replace_with, text)
 
 
-def replace_numbers(text, replace_with='*NUMBER*'):
+def replace_numbers(text, replace_with="*NUMBER*"):
     """Replace all numbers in ``text`` str with ``replace_with`` str."""
-    return constants.NUMBERS_REGEX.sub(replace_with, text)
+    return constants.RE_NUMBERS.sub(replace_with, text)
 
 
 def replace_currency_symbols(text, replace_with=None):
@@ -118,7 +116,7 @@ def replace_currency_symbols(text, replace_with=None):
             text = text.replace(k, v)
         return text
     else:
-        return constants.CURRENCY_REGEX.sub(replace_with, text)
+        return constants.RE_CURRENCY.sub(replace_with, text)
 
 
 def remove_punct(text, marks=None):
@@ -141,12 +139,12 @@ def remove_punct(text, marks=None):
         instead. The former's performance is about 5-10x faster.
     """
     if marks:
-        return re.sub('[{}]+'.format(re.escape(marks)), ' ', text, flags=re.UNICODE)
+        return re.sub("[{}]+".format(re.escape(marks)), " ", text, flags=re.UNICODE)
     else:
-        return text.translate(constants.PUNCT_TRANSLATE_UNICODE)
+        return text.translate(constants.PUNCT_TRANSLATE_UNICODE.data)
 
 
-def remove_accents(text, method='unicode'):
+def remove_accents(text, method="unicode"):
     """
     Remove accents from any accented unicode characters in ``text`` str, either by
     transforming them into ascii equivalents or removing them entirely.
@@ -165,20 +163,36 @@ def remove_accents(text, method='unicode'):
     Raises:
         ValueError: if ``method`` is not in {'unicode', 'ascii'}
     """
-    if method == 'unicode':
-        return ''.join(c for c in unicodedata.normalize('NFKD', text)
-                       if not unicodedata.combining(c))
-    elif method == 'ascii':
-        return unicodedata.normalize('NFKD', text).encode('ascii', errors='ignore').decode('ascii')
+    if method == "unicode":
+        return "".join(
+            c
+            for c in unicodedata.normalize("NFKD", text)
+            if not unicodedata.combining(c)
+        )
+    elif method == "ascii":
+        return (
+            unicodedata.normalize("NFKD", text)
+            .encode("ascii", errors="ignore")
+            .decode("ascii")
+        )
     else:
         msg = '`method` must be either "unicode" and "ascii", not {}'.format(method)
         raise ValueError(msg)
 
 
-def preprocess_text(text, fix_unicode=False, lowercase=False, transliterate=False,
-                    no_urls=False, no_emails=False, no_phone_numbers=False,
-                    no_numbers=False, no_currency_symbols=False, no_punct=False,
-                    no_contractions=False, no_accents=False):
+def preprocess_text(
+    text,
+    fix_unicode=False,
+    lowercase=False,
+    no_urls=False,
+    no_emails=False,
+    no_phone_numbers=False,
+    no_numbers=False,
+    no_currency_symbols=False,
+    no_punct=False,
+    no_contractions=False,
+    no_accents=False,
+):
     """
     Normalize various aspects of a raw text doc before parsing it with Spacy.
     A convenience function for applying all other preprocessing functions in one go.
@@ -188,8 +202,6 @@ def preprocess_text(text, fix_unicode=False, lowercase=False, transliterate=Fals
         fix_unicode (bool): if True, fix "broken" unicode such as
             mojibake and garbled HTML entities
         lowercase (bool): if True, all text is lower-cased
-        transliterate (bool): if True, convert non-ascii characters
-            into their closest ascii equivalents
         no_urls (bool): if True, replace all URL strings with '*URL*'
         no_emails (bool): if True, replace all email strings with '*EMAIL*'
         no_phone_numbers (bool): if True, replace all phone number strings
@@ -203,8 +215,7 @@ def preprocess_text(text, fix_unicode=False, lowercase=False, transliterate=Fals
         no_contractions (bool): if True, replace *English* contractions
             with their unshortened forms
         no_accents (bool): if True, replace all accented characters
-            with unaccented versions; NB: if `transliterate` is True, this option
-            is redundant
+            with unaccented versions
 
     Returns:
         str: input ``text`` processed according to function args
@@ -214,9 +225,7 @@ def preprocess_text(text, fix_unicode=False, lowercase=False, transliterate=Fals
         on the text, so choose carefully, and preprocess at your own risk!
     """
     if fix_unicode is True:
-        text = fix_bad_unicode(text, normalization='NFC')
-    if transliterate is True:
-        text = transliterate_unicode(text)
+        text = fix_bad_unicode(text, normalization="NFC")
     if no_urls is True:
         text = replace_urls(text)
     if no_emails is True:
@@ -230,7 +239,7 @@ def preprocess_text(text, fix_unicode=False, lowercase=False, transliterate=Fals
     if no_contractions is True:
         text = unpack_contractions(text)
     if no_accents is True:
-        text = remove_accents(text, method='unicode')
+        text = remove_accents(text, method="unicode")
     if no_punct is True:
         text = remove_punct(text)
     if lowercase is True:
