@@ -13,29 +13,30 @@ import warnings
 
 import numpy as np
 from cytoolz import itertoolz
-from Levenshtein import (distance as _levenshtein,
-                         hamming as _hamming,
-                         jaro_winkler as _jaro_winkler,
-                         ratio as _ratio)
+from Levenshtein import (
+    distance as _levenshtein,
+    hamming as _hamming,
+    jaro_winkler as _jaro_winkler,
+    ratio as _ratio,
+)
 from pyemd import emd
 from sklearn.metrics import pairwise_distances
 
 from . import compat
 from . import extract
-from .doc import Doc
 
 
-NONWORDCHARS_REGEX = re.compile(r'\W+', flags=re.IGNORECASE | re.UNICODE)
+RE_NONWORDCHARS = re.compile(r"\W+", flags=re.IGNORECASE | re.UNICODE)
 
 
-def word_movers(doc1, doc2, metric='cosine'):
+def word_movers(doc1, doc2, metric="cosine"):
     """
     Measure the semantic similarity between two documents using Word Movers
     Distance.
 
     Args:
-        doc1 (:class:`textacy.Doc` or :class:`spacy.Doc`)
-        doc2 (:class:`textacy.Doc` or :class:`spacy.Doc`)
+        doc1 (:class:`spacy.tokens.Doc`)
+        doc2 (:class:`spacy.tokens.Doc`)
         metric ({'cosine', 'euclidean', 'l1', 'l2', 'manhattan'})
 
     Returns:
@@ -59,21 +60,25 @@ def word_movers(doc1, doc2, metric='cosine'):
         if word.has_vector and word_idxs.setdefault(word.orth, n) == n:
             word_vecs.append(word.vector)
             n += 1
-    distance_mat = pairwise_distances(np.array(word_vecs), metric=metric).astype(np.double)
+    distance_mat = pairwise_distances(np.array(word_vecs), metric=metric).astype(
+        np.double
+    )
     distance_mat /= distance_mat.max()
 
     vec1 = collections.Counter(
-        word_idxs[word.orth]
-        for word in extract.words(doc1)
-        if word.has_vector)
-    vec1 = np.array([vec1[word_idx] for word_idx in compat.range_(len(word_idxs))]).astype(np.double)
+        word_idxs[word.orth] for word in extract.words(doc1) if word.has_vector
+    )
+    vec1 = np.array(
+        [vec1[word_idx] for word_idx in compat.range_(len(word_idxs))]
+    ).astype(np.double)
     vec1 /= vec1.sum()  # normalize word counts
 
     vec2 = collections.Counter(
-        word_idxs[word.orth]
-        for word in extract.words(doc2)
-        if word.has_vector)
-    vec2 = np.array([vec2[word_idx] for word_idx in compat.range_(len(word_idxs))]).astype(np.double)
+        word_idxs[word.orth] for word in extract.words(doc2) if word.has_vector
+    )
+    vec2 = np.array(
+        [vec2[word_idx] for word_idx in compat.range_(len(word_idxs))]
+    ).astype(np.double)
     vec2 /= vec2.sum()  # normalize word counts
 
     return 1.0 - emd(vec1, vec2, distance_mat)
@@ -81,21 +86,18 @@ def word_movers(doc1, doc2, metric='cosine'):
 
 def word2vec(obj1, obj2):
     """
-    Measure the semantic similarity between one Doc or spacy Doc, Span, Token,
+    Measure the semantic similarity between one spacy Doc, Span, Token,
     or Lexeme and another like object using the cosine distance between the
     objects' (average) word2vec vectors.
 
     Args:
-        obj1 (``textacy.Doc``, ``spacy.Doc``, ``spacy.Span``, ``spacy.Token``, or ``spacy.Lexeme``)
-        obj2 (``textacy.Doc``, ``spacy.Doc``, ``spacy.Span``, ``spacy.Token``, or ``spacy.Lexeme``)
+        obj1 (:class:`spacy.tokens.Doc`, :class:`spacy.tokens.Span`, :class:`spacy.tokens.Token`, or ``spacy.Lexeme``)
+        obj2 (:class:`spacy.tokens.Doc`, :class:`spacy.tokens.Span`, :class:`spacy.tokens.Token`, or ``spacy.Lexeme``)
 
     Returns
-        float: similarity between `obj1` and `obj2` in the interval [0.0, 1.0],
+        float: similarity between ``obj1`` and ``obj2`` in the interval [0.0, 1.0],
         where larger values correspond to more similar objects
     """
-    if isinstance(obj1, Doc) and isinstance(obj2, Doc):
-        obj1 = obj1.spacy_doc
-        obj2 = obj2.spacy_doc
     return obj1.similarity(obj2)
 
 
@@ -103,7 +105,7 @@ def jaccard(obj1, obj2, fuzzy_match=False, match_threshold=0.8):
     """
     Measure the semantic similarity between two strings or sequences of strings
     using Jaccard distance, with optional fuzzy matching of not-identical pairs
-    when `obj1` and `obj2` are sequences of strings.
+    when ``obj1`` and ``obj2`` are sequences of strings.
 
     Args:
         obj1 (str or Sequence[str])
@@ -115,25 +117,28 @@ def jaccard(obj1, obj2, fuzzy_match=False, match_threshold=0.8):
             with a score >= this value will be considered matches
 
     Returns:
-        float: similarity between `obj1` and `obj2` in the interval [0.0, 1.0],
+        float: similarity between ``obj1`` and ``obj2`` in the interval [0.0, 1.0],
         where larger values correspond to more similar strings or sequences
         of strings
 
     Raises:
-        ValueError: if `fuzzy_match` is True but `obj1` and `obj2` are strings
+        ValueError: if ``fuzzy_match`` is True but ``obj1`` and ``obj2`` are strings
     """
     if isinstance(match_threshold, int) and 1 <= match_threshold <= 100:
         warnings.warn(
-            '`match_threshold` should be a float in [0.0, 1.0]; '
-            'it was automatically converted from the provided int in [0, 100]')
+            "`match_threshold` should be a float in [0.0, 1.0]; "
+            "it was automatically converted from the provided int in [0, 100]"
+        )
         match_threshold /= 100
     set1 = set(obj1)
     set2 = set(obj2)
     intersection = len(set1 & set2)
     union = len(set1 | set2)
-    if (fuzzy_match is True and
-            not isinstance(obj1, compat.string_types) and
-            not isinstance(obj2, compat.string_types)):
+    if (
+        fuzzy_match is True
+        and not isinstance(obj1, compat.string_types)
+        and not isinstance(obj2, compat.string_types)
+    ):
         for item1 in set1.difference(set2):
             if max(token_sort_ratio(item1, item2) for item2 in set2) >= match_threshold:
                 intersection += 1
@@ -141,7 +146,7 @@ def jaccard(obj1, obj2, fuzzy_match=False, match_threshold=0.8):
             if max(token_sort_ratio(item2, item1) for item1 in set1) >= match_threshold:
                 intersection += 1
     elif fuzzy_match is True:
-        raise ValueError('fuzzy matching not possible with str inputs')
+        raise ValueError("fuzzy matching not possible with str inputs")
 
     return intersection / union
 
@@ -157,7 +162,7 @@ def hamming(str1, str2):
         str2 (str)
 
     Returns:
-        float: similarity between `str1` and `str2` in the interval [0.0, 1.0],
+        float: similarity between ``str1`` and ``str2`` in the interval [0.0, 1.0],
         where larger values correspond to more similar strings
 
     Note:
@@ -193,7 +198,7 @@ def levenshtein(str1, str2):
             of characters in the longest string; otherwise leave the distance as-is
 
     Returns:
-        float: similarity between `str1` and `str2` in the interval [0.0, 1.0],
+        float: similarity between ``str1`` and ``str2`` in the interval [0.0, 1.0],
         where larger values correspond to more similar strings
     """
     distance = _levenshtein(str1, str2)
@@ -213,7 +218,7 @@ def jaro_winkler(str1, str2, prefix_weight=0.1):
             to consider the strings identical
 
     Returns:
-        float: similarity between `str1` and `str2` in the interval [0.0, 1.0],
+        float: similarity between ``str1`` and ``str2`` in the interval [0.0, 1.0],
         where larger values correspond to more similar strings
     """
     return _jaro_winkler(str1, str2, prefix_weight)
@@ -234,26 +239,16 @@ def token_sort_ratio(str1, str2):
     """
     if not str1 or not str2:
         return 0
-    str1 = _force_unicode(str1)
-    str2 = _force_unicode(str2)
+    str1 = compat.to_unicode(str1)
+    str2 = compat.to_unicode(str2)
     str1_proc = _process_and_sort(str1)
     str2_proc = _process_and_sort(str2)
     return _ratio(str1_proc, str2_proc)
 
 
-def _force_unicode(s):
-    """Force ``s`` into unicode, or die trying."""
-    if isinstance(s, compat.unicode_):
-        return s
-    elif isinstance(s, compat.bytes_):
-        return compat.bytes_to_unicode(s)
-    else:
-        return compat.unicode_(s)
-
-
 def _process_and_sort(s):
     """Return a processed string with tokens sorted then re-joined."""
-    return ' '.join(sorted(_process(s).split()))
+    return " ".join(sorted(_process(s).split()))
 
 
 def _process(s):
@@ -262,5 +257,5 @@ def _process(s):
     and force everything to lower-case.
     """
     if not s:
-        return ''
-    return NONWORDCHARS_REGEX.sub(' ', s).lower().strip()
+        return ""
+    return RE_NONWORDCHARS.sub(" ", s).lower().strip()
