@@ -8,8 +8,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import logging
 
-from spacy.attrs import intify_attrs
-from spacy.tokens import Doc as SpacyDoc
+from spacy.tokens import Doc
 
 from . import utils as spacier_utils
 from .. import compat
@@ -22,7 +21,7 @@ class TextStatsComponent(object):
     """
     A custom component to be added to a spaCy language pipeline that computes
     one, some, or all text stats for a parsed doc and sets the values
-    as custom attributes on a :obj:`SpacyDoc`.
+    as custom attributes on a :class:`spacy.tokens.Doc`.
 
     Add the component to a pipeline, *after* the parser (as well as any
     subsequent components that modify the tokens/sentences of the doc)::
@@ -66,25 +65,37 @@ class TextStatsComponent(object):
         :class:`textacy.text_stats.TextStats`
     """
 
-    name = 'textacy_text_stats'
+    name = "textacy_text_stats"
 
     def __init__(self, attrs=None):
         if attrs is None:
             self.attrs = (
-                'n_sents', 'n_words', 'n_chars', 'n_syllables',
-                'n_unique_words', 'n_long_words',
-                'n_monosyllable_words', 'n_polysyllable_words',
-                'flesch_kincaid_grade_level', 'flesch_reading_ease',
-                'smog_index', 'gunning_fog_index', 'coleman_liau_index',
-                'automated_readability_index', 'lix', 'gulpease_index',
-                'wiener_sachtextformel',
+                "n_sents",
+                "n_words",
+                "n_chars",
+                "n_syllables",
+                "n_unique_words",
+                "n_long_words",
+                "n_monosyllable_words",
+                "n_polysyllable_words",
+                "flesch_kincaid_grade_level",
+                "flesch_reading_ease",
+                "smog_index",
+                "gunning_fog_index",
+                "coleman_liau_index",
+                "automated_readability_index",
+                "lix",
+                "gulpease_index",
+                "wiener_sachtextformel",
             )
         elif isinstance(attrs, compat.string_types):
             self.attrs = (attrs,)
         else:
             self.attrs = tuple(attrs)
         for attr in self.attrs:
-            SpacyDoc.set_extension(attr, default=None, force=True)
+            # TODO: see if there's a better way to handle this
+            # that doesn't involve clobbering existing property extensions
+            Doc.set_extension(attr, default=None, force=True)
             LOGGER.debug('"%s" custom attribute added to `spacy.tokens.Doc`')
 
     def __call__(self, doc):
@@ -95,9 +106,10 @@ class TextStatsComponent(object):
             except AttributeError:
                 LOGGER.exception(
                     "`TextStats` class doesn't have '%s' attribute, so it can't "
-                    "be set on this `SpacyDoc`. Check the attrs used to initialize "
+                    "be set on this `Doc`. Check the attrs used to initialize "
                     "the `TextStatsComponent` in this pipeline for errors.",
-                    attr)
+                    attr,
+                )
                 raise
         return doc
 
@@ -107,17 +119,17 @@ def merge_entities(doc):
     Merge named entities into single tokens in ``doc``, *in-place*. Can be used
     as a stand-alone function, or as part of a spaCy language pipeline::
 
-        >>> spacy_lang = textacy.load_spacy('en')
+        >>> spacy_lang = textacy.load_spacy_lang('en')
         >>> spacy_lang.add_pipe(merge_entities, after='ner')
         >>> doc = spacy_lang('Burton DeWilde is an entity in this sentence.')
         >>> doc[0]
         Burton DeWilde
 
     Args:
-        doc (``SpacyDoc``)
+        doc (:class:`spacy.tokens.Doc`)
 
     Returns:
-        ``SpacyDoc``: Input ``doc`` with entities merged.
+        :class:`spacy.tokens.Doc`: Input ``doc`` with entities merged.
     """
     spacier_utils.merge_spans(doc.ents, doc)
     return doc
